<?php

namespace ZPOS\API;

use WP_REST_Server;
use WC_REST_Products_Controller;
use ZPOS\Structure\AddDefaultImage;
use ZPOS\Structure\ProductResponse;

class Products extends WC_REST_Products_Controller
{
	use AddDefaultImage, ProductResponse;

	protected $namespace = 'wc-pos';
	protected $rest_base = 'products';

	public function __construct()
	{
		parent::__construct();
		add_filter('woocommerce_rest_check_permissions', function ($permission, $context, $object_id, $post_type) {
			if (is_array($post_type)) {
				$permissions = array_map(function ($type) use ($context, $object_id) {
					return wc_rest_check_post_permissions($type, $context, $object_id);
				}, $post_type);

				$permission = array_reduce($permissions, function ($a, $b) {
					return $a && $b;
				}, true);
			}
			return $permission;
		}, 10, 4);

		add_filter("woocommerce_rest_prepare_{$this->post_type}_object", [$this, 'add_default_images'], 1000);
	}

	public function get_collection_params()
	{
		$params = parent::get_collection_params();

		$params['orderby']['enum'][] = 'parent_id';

		return $params;
	}

	public function register_routes()
	{
		parent::register_routes();

		register_rest_route(
			$this->namespace,
			'/' . $this->rest_base . '/ids',
			[
				'methods' => WP_REST_Server::READABLE,
				'callback' => [$this, 'get_all_ids'],
				'permission_callback' => [$this, 'get_items_permissions_check'],
			]
		);
	}

	public function get_all_ids($request)
	{
		$args = [
			'post_type' => $this->post_type,
			'post_status' => ['publish', 'trash'],
			'posts_per_page' => -1,
			'fields' => 'ids',
		];

		if (isset($request['updated_at_min'])) {
			$args['date_query']['updated_at_min'] = [
				'column' => 'post_modified_gmt',
				'after' => $request['updated_at_min'],
				'inclusive' => false
			];
		}

		$query = new \WP_Query($args);
		return $query->posts;
	}
}
