<?php

namespace ZPOS\API\Setting;

use WP_REST_Server, WC_REST_Setting_Options_Controller;

class Option extends WC_REST_Setting_Options_Controller
{
	protected $namespace = 'wc-pos';

	public function __construct()
	{
		$this->register_pos_settings_options();
		$this->register_plugins_settings_options();

		if (defined('\Zprint\ACTIVE') && \Zprint\ACTIVE) {
			$this->register_print_settings_options();
		}
		if (defined('\Zhours\ACTIVE') && \Zhours\ACTIVE) {
			$this->register_hours_settings_options();
		}
	}

	protected function register_plugins_settings_options()
	{
		add_filter('pre_option_zprint_enabled', function () {
			return defined('\Zprint\ACTIVE') && \Zprint\ACTIVE ? "yes" : "no";
		});

		add_filter('pre_option_zhours_enabled', function () {
			return defined('\Zhours\ACTIVE') && \Zhours\ACTIVE ? "yes" : "no";
		});

		add_filter('pre_option_zaddons_enabled', function () {
			return defined('\ZAddons\ACTIVE') && \ZAddons\ACTIVE ? "yes" : "no";
		});

		add_filter(
			'woocommerce_settings-plugins',
			function ($setting) {
				$setting[] = [
					'id' => 'zprint_enabled',
					'label' => 'zPrint Status',
					'type' => 'checkbox',
					'option_key' => 'zprint_enabled',
				];

				$setting[] = [
					'id' => 'zhours_enabled',
					'label' => 'zHours Status',
					'type' => 'checkbox',
					'option_key' => 'zhours_enabled',
				];

				$setting[] = [
					'id' => 'zaddons_enabled',
					'label' => 'zAddons Status',
					'type' => 'checkbox',
					'option_key' => 'zaddons_enabled',
				];

				return $setting;
			},
			100
		);
	}

	protected function register_pos_settings_options()
	{
		add_filter(
			'woocommerce_settings-pos',
			function ($setting) {
				$setting[] = [
					'id' => 'zpos_tips_enabled',
					'label' => 'zPOS Tips Enabled',
					'type' => 'checkbox',
					'option_key' => 'pos_tips',
					'default' => 'no',
				];

				$setting[] = [
					'id' => 'pos_tax_enabled',
					'label' => 'Tax Calculation',
					'type' => 'select',
					'option_key' => 'pos_tax_enabled',
					'default' => 'on',
				];

				$setting[] = [
					'id' => 'pos_tax_based_on_order',
					'label' => 'Calculate Tax Based on',
					'type' => 'checkbox',
					'option_key' => 'pos_tax_based_on_order',
					'default' => ['shipping', 'billing', 'pos', 'wc'],
				];

				$setting[] = [
					'id' => 'pos_cart_customer',
					'label' => 'Required Customer',
					'type' => 'checkbox',
					'option_key' => 'pos_cart_customer',
					'default' => 'off',
				];

				$setting[] = [
					'id' => 'pos_cart_menu_display',
					'label' => 'Menu Display',
					'type' => 'checkbox',
					'option_key' => 'pos_cart_menu_display',
					'default' => 'off',
				];

				$setting[] = [
					'id' => 'pos_coupons_manual',
					'label' => 'Enable Manual Coupons',
					'type' => 'checkbox',
					'option_key' => 'pos_coupons_manual',
					'default' => 'off',
				];

				return $setting;
			},
			100
		);
	}

	protected function register_print_settings_options()
	{
		add_filter(
			'woocommerce_settings-zprint',
			function ($setting) {
				$setting[] = [
					'id' => 'zprint_print_pos',
					'label' => 'Print POS',
					'type' => 'checkbox',
					'option_key' => 'zprint_print_pos',
				];
				$setting[] = [
					'id' => 'zprint_print_pos_order_only',
					'label' => 'Print POS Order Only',
					'type' => 'checkbox',
					'option_key' => 'zprint_print_pos_order_only',
				];
				$setting[] = [
					'id' => 'zprint_print_web',
					'label' => 'Print WEB',
					'type' => 'checkbox',
					'option_key' => 'zprint_print_web',
				];
				return $setting;
			},
			100
		);
	}

	protected function register_hours_settings_options()
	{
		add_filter(
			'woocommerce_settings-zhours',
			function ($setting) {
				$setting[] = [
					'id' => 'zhours_current_status',
					'label' => 'zHours Status',
					'type' => 'checkbox',
					'option_key' => 'zhours_current_status',
				];
				return $setting;
			},
			100
		);
	}

	public function get_items_permissions_check($request)
	{
		return parent::get_item_permissions_check($request) ||
			current_user_can('read_woocommerce_pos_setting');
	}
}
