<?php

namespace ZPOS\API;

use WP_REST_Server;
use WC_REST_Taxes_Controller;
use ZPOS\Structure\EmptyEntity;

class Taxes extends WC_REST_Taxes_Controller
{
	protected $namespace = 'wc-pos';

	public function register_routes()
	{
		parent::register_routes();

		register_rest_route($this->namespace, '/' . $this->rest_base . '/shop', [
			[
				'methods' => WP_REST_Server::READABLE,
				'callback' => [$this, 'get_shop_items'],
				'permission_callback' => [$this, 'get_items_permissions_check'],
			]
		]);
	}

	public function get_shop_items()
	{
		$empty_entity = new EmptyEntity(); 
		return array_values($this->get_current_taxes_rates($empty_entity, ''));
	}

	public function get_items_permissions_check($request)
	{
		return parent::get_item_permissions_check($request) || current_user_can('read_woocommerce_pos_setting');
	}


	/**
	 * @param $entity \WC_Order|\WC_Customer|EmptyEntity
	 * @param $tax_class
	 * @return array
	 */
	public static function get_current_taxes_rates($entity, $tax_class)
	{
		$options = get_option('pos_tax_based_on_order');
		foreach ($options as $option) {
			if ($option === "shipping") {
				if (empty($entity->get_shipping_country())) {
					continue;
				}
				return \WC_Tax::find_rates([
					'country' => $entity->get_shipping_country(),
					'state' => $entity->get_shipping_state(),
					'city' => $entity->get_shipping_city(),
					'postcode' => $entity->get_shipping_postcode(),
					'tax_class' => $tax_class
				]);
			}
			if ($option === "billing") {
				if (empty($entity->get_billing_country())) {
					continue;
				}
				return \WC_Tax::find_rates([
					'country' => $entity->get_billing_country(),
					'state' => $entity->get_billing_state(),
					'city' => $entity->get_billing_city(),
					'postcode' => $entity->get_billing_postcode(),
					'tax_class' => $tax_class
				]);
			}
			if ($option === "pos") {
				if (empty(get_option('pos_country'))) {
					continue;
				}
				return \WC_Tax::find_rates([
					'country' => get_option('pos_country'),
					'state' => get_option('pos_state'),
					'city' => get_option('pos_city'),
					'postcode' => get_option('pos_postcode'),
					'tax_class' => $tax_class
				]);
			}
			
			return \WC_Tax::get_base_tax_rates($tax_class);
		}
	}
}
