<?php

namespace ZPOS\Admin;

use ZPOS\Plugin;

class Menu
{
	public $slug;
	public $links;
	public $kiosk = \ZPOS\PLUGIN_NAME;

	public function __construct($slug)
	{
		$this->slug = $slug;

		add_action('admin_menu', [$this, 'init']);
		add_action('admin_enqueue_scripts', [$this, 'scripts']);
	}

	public function init()
	{
		global $submenu;
		if (!wp_get_current_user()->has_cap('manage_woocommerce_pos')) {
			return false;
		}

		add_menu_page('POS', 'POS', 'manage_woocommerce_pos', $this->links[0]->slug, [$this->links[0], 'render'], 'dashicons-plane', $this->slug);

		for ($l = 1; $l < count($this->links); $l++) {
			$link = $this->links[$l];

			add_submenu_page($this->slug, $link->title, $link->title, 'manage_woocommerce_pos', $link->slug, [$link, 'render']);
		}

		add_submenu_page($this->slug, 'View POS', 'View POS', 'access_woocommerce_pos', null);
		add_submenu_page($this->slug, 'Add-ons', 'Add-ons', 'access_woocommerce_pos', null);

		$pos_submenu = &$submenu[$this->slug];

		$setting = $pos_submenu[0];
		$setting[0] = 'Settings';
		$pos = $pos_submenu[1];
		$pos[2] = $this->getPosLink();
		$addons = $pos_submenu[2];
		$addons[2] = add_query_arg('page', $this->slug, admin_url('admin.php')) . "#/addons";

		$pos_submenu[0] = $pos;
		$pos_submenu[1] = $addons;
		$pos_submenu[2] = $setting;
	}

	public function scripts()
	{
		wp_enqueue_script('pos_menu', Plugin::getAssetUrl('menu.js'), ['pos_commons']);
		if (Plugin::getManifest('menu.css')) {
			wp_enqueue_style('pos_menu', Plugin::getAssetUrl('menu.css'));
		}
	}

	public function getPosLink()
	{
		return home_url($this->kiosk, is_ssl());
	}
}
