<?php

namespace ZPOS\Admin;

use ZPOS\Admin\Tabs\Addons;
use ZPOS\Admin\Tabs\General;
use ZPOS\Admin\Tabs\Gateway;
use ZPOS\Admin\Tabs\Products;
use ZPOS\Admin\Tabs\Cart;
use ZPOS\Admin\Tabs\Tax;
use ZPOS\Admin\Tabs\Users;
use ZPOS\Admin\Tabs\Debug;
use ZPOS\Plugin;

class Setting
{
	protected $tabs;
	public $slug;

	public function __construct($slug)
	{
		$this->slug = $slug;

		add_action('admin_enqueue_scripts', [$this, 'scripts']);

		$this->tabs = [
			new General(),
			new Products(),
			new Cart(),
			new Gateway(),
			new Addons(),
			new Users(),
			new Tax(),
			new Debug(),
		];
	}

	public function scripts()
	{
		if ($this->isRequested()) {
			wp_enqueue_script('thickbox');
			wp_enqueue_style('thickbox');
			wp_enqueue_script('media-upload');

			wp_enqueue_script('pos_admin', Plugin::getAssetUrl('admin.js'), ['pos_commons'], false, true);

			if (Plugin::getManifest('admin.css')) {
				wp_enqueue_style('pos_admin', Plugin::getAssetUrl('admin.css'));
			}
		}
	}

	public function getJson()
	{
		return json_encode(
			array_map(function ($e) {
				/* @var $e */
				return $e->toJSON();
			}, $this->tabs)
		);
	}

	public function submit_button()
	{
		ob_start();
		submit_button();
		$data = ob_get_contents();
		ob_end_clean();

		return json_encode($data);
	}

	public function render()
	{
		?>
		<form action="<?= admin_url('options.php'); ?>" method="post">
			<script>
				window.SETTING = <?= $this->getJson(); ?>;
				window.SUBMIT_BUTTON = <?= $this->submit_button(); ?>;
			</script>
			<div id="root"></div>

		</form>
		<?php
	}

	protected function getUrl()
	{
		return add_query_arg('page', $this->slug, admin_url('admin.php'));
	}

	public function isRequested()
	{
		$current_url =
			(is_ssl() ? 'https://' : 'http://') . $_SERVER['SERVER_NAME'] . $_SERVER['REQUEST_URI'];

		$admin_page = parse_url($this->getUrl());
		$current = parse_url($current_url);

		$diff = array_diff($admin_page, $current);

		if (isset($diff['path'])) {
			return false;
		}

		$admin_page_query = parse_url($this->getUrl(), PHP_URL_QUERY);
		$current_query = parse_url($current_url, PHP_URL_QUERY);

		parse_str($admin_page_query, $admin_page_query);
		parse_str($current_query, $current_query);

		$diff = array_diff($admin_page_query, $current_query);

		return count($diff) === 0;
	}
}
