<?php

namespace ZPOS\Admin\Tabs;

use ZPOS\Structure\ArrayObject;
use ZPOS\Admin\Setting\Tab;
use ZPOS\Admin\Setting\Box;
use ZPOS\Admin\Setting\Input\PluginWidgets;

abstract class AddonsBase extends Tab
{
	public $exact = true;
	public $name = 'Add-ons';
	public $path = '/addons';

	public function admin_init()
	{
		$this->boxes[] = new Box(
			null,
			null,
			new PluginWidgets('Plugins', $this->get_plugins()),
			new PluginWidgets('Pro Plugin', $this->get_pro()),
			new PluginWidgets('Plugins by Other Developers', $this->get_other_plugins())
		);
	}

	protected function get_default_plugins()
	{
		return [
			'order-hours-scheduler-woocommerce' => [
				'Title' => 'Order Hours',
				'TextDomain' => 'order-hours-scheduler-woocommerce',
				'Description' => 'Add the ability to configure the WooCommerce store hours toggling the ability to block customers during checkout from an online and offline mode.',
				'URI' => 'http://www.bizswoop.com/pos/hours',
				'Installed' => false,
				'Status' => false
			],
			'Product-Add-Ons-WooCommerce' => [
				'Title' => 'Product Add-ons',
				'TextDomain' => 'Product-Add-Ons-WooCommerce',
				'Description' => 'Enable the ability to add product add-ons and modifiers to each product listing',
				'URI' => ' https://www.bizswoop.com/wp/productaddons',
				'Installed' => false,
				'Status' => false
			],
			'Print-Google-Cloud-Print-GCP-WooCommerce' => [
				'Title' => 'POS Print for Google Cloud Print',
				'TextDomain' => 'Print-Google-Cloud-Print-GCP-WooCommerce',
				'Description' => 'Enable remote printing to multiple printers using Google Cloud Print technology',
				'URI' => 'http://www.bizswoop.com/pos/print',
				'Installed' => false,
				'Status' => false
			]
		];
	}

	protected function get_plugins()
	{
		$plugins = $this->get_default_plugins();

		return (new ArrayObject(get_plugins()))
			->filter(function ($plugin) use ($plugins) {
				return in_array($plugin['TextDomain'], array_keys($plugins));
			})
			->map(function ($plugin, $key) {
				return [
					'Title' => $plugin['Title'],
					'TextDomain' => $plugin['TextDomain'],
					'Description' => $plugin['Description'],
					'URI' => $plugin['PluginURI'],
					'Installed' => true,
					'Status' => is_plugin_active($key),
					'Enable' => ['type' => 'link', 'to' => admin_url('plugins.php')]
				];
			})
			->setKeys(function ($el) {
				return $el['TextDomain'];
			})
			->merge($plugins, ArrayObject::BEFORE)
			->map(function ($plugin) {
				return array_combine(array_map('strtolower', array_keys($plugin)), $plugin);
			})
			->values()
			->get();
	}

	protected function get_pro()
	{
		return (new ArrayObject([
			[
				'Title' => 'Multiple Users Assignments',
				'TextDomain' => 'zpos_pro',
				'Description' => 'Buy Multiple Users Assignments for the POS',
				'URI' => admin_url('plugin-install.php'),
				'BUY' => 'https://www.bizswoop.com/wp/pos/users/#buy',
				'MORE' => 'https://www.bizswoop.com/wp/pos/users',
				'Installed' => false,
				'Status' => false,
			]
		]))
			->map(function ($plugin) {
				return array_combine(array_map('strtolower', array_keys($plugin)), $plugin);
			})
			->get();
	}

	protected function get_default_other_plugins()
	{
		return [
			'woocommerce-gateway-stripe' => [
				'Title' => ' Payment Gateway Stripe',
				'TextDomain' => 'woocommerce-gateway-stripe',
				'Description' => 'POS support for Stripe payment processing',
				'URI' => 'https://wordpress.org/plugins/woocommerce-gateway-stripe/',
				'Installed' => false,
				'Status' => false
			]
		];
	}

	protected function get_other_plugins()
	{
		$plugins = $this->get_default_other_plugins();

		return (new ArrayObject(get_plugins()))
			->filter(function ($plugin) use ($plugins) {
				return in_array($plugin['TextDomain'], array_keys($plugins));
			})
			->map(function ($plugin, $key) {
				return [
					'Title' => $plugin['Title'],
					'TextDomain' => $plugin['TextDomain'],
					'Description' => $plugin['Description'],
					'URI' => $plugin['PluginURI'],
					'Installed' => true,
					'Status' => is_plugin_active($key),
					'Enable' => ['type' => 'link', 'to' => admin_url('plugins.php')]
				];
			})
			->setKeys(function ($el) {
				return $el['TextDomain'];
			})
			->merge($plugins, ArrayObject::BEFORE)
			->map(function ($plugin) {
				return array_combine(array_map('strtolower', array_keys($plugin)), $plugin);
			})
			->values()
			->get();
	}
}
