<?php

namespace ZPOS\Admin\Tabs;

use ZPOS\Admin\Setting\Box;
use ZPOS\Admin\Setting\Input\Checkbox;
use ZPOS\Admin\Setting\Input\GatewayArray;
use ZPOS\Admin\Setting\Tab;

class Gateway extends Tab
{
	public $name = 'Gateway';
	public $path = '/gateway';

	public function admin_init()
	{
		$this->boxes[] = new Box(
			null,
			null,
			new Checkbox('Customer Tips', 'pos_tips', $this->get_tips_value(), "Enable Tip on Checkout"),
			new GatewayArray(
				'Payment Gateways',
				'pos_gateways',
				$this->get_payment_value(),
				"Installed gateways are listed below. Drag and drop gateways to control their display order at the Point of Sale.\n Payment Gateways enabled here will be available at the Point of Sale. Payment Gateways enabled on the settings page will be available on your Online Store."
			)
		);
	}

	public function init()
	{
		register_setting('pos' . $this->path, 'pos_tips', [
			'default' => "no",
		]);

		register_setting('pos' . $this->path, 'pos_gateways', [
			'default' => [
				"pos_cash" => [
					"order" => 0,
					"pos" => true,
				],
				"pos_card_smart" => [
					"order" => 1,
					"pos" => true,
				],
			],
		]);
		register_setting('pos' . $this->path, 'pos_gateways_default', [
			'default' => "pos_cash",
		]);

		array_map([$this, 'register_gateway_setting'], WC()->payment_gateways->payment_gateways());
	}

	private function register_gateway_setting(\WC_Payment_Gateway $gateway)
	{
		register_setting('pos' . $this->path . '/' . $gateway->id, $gateway->get_option_key());
	}

	private function get_tips_value()
	{
		return in_array(get_option("pos_tips"), ["yes", "on"]);
	}

	private function get_payment_value()
	{
		$gateways = WC()->payment_gateways->payment_gateways();

		$data = array_map([$this, 'prepare_gateway'], $gateways);
		usort($data, function ($a, $b) {
			$a_order = $this->get_order($a);
			$b_order = $this->get_order($b);

			return $a_order - $b_order;
		});

		return $data;
	}

	private function get_order($gateway)
	{
		$gateways_data = get_option('pos_gateways');
		$order = isset($gateways_data[$gateway['id']])
			? (int) $gateways_data[$gateway['id']]["order"]
			: 9999;
		return $order;
	}

	private function prepare_gateway(\WC_Payment_Gateway $gateway)
	{
		$gateways_data = get_option('pos_gateways');

		$pos =
			isset($gateways_data[$gateway->id]) && isset($gateways_data[$gateway->id]["pos"])
				? (bool) $gateways_data[$gateway->id]["pos"]
				: false;

		return [
			'id' => $gateway->id,
			'method_title' => $gateway->method_title,
			'title' => $gateway->title,
			'description' => $gateway->description,
			'default' => get_option('pos_gateways_default') === $gateway->id,
			'name' => $gateway->get_option_key(),
			'online' => $gateway->enabled === "yes",
			'pos' => $pos,
			'gateway_settings_fields' => $this->gateway_settings_fields($gateway),
			'setting' => $gateway->supports("pos")
				? null
				: admin_url('admin.php?page=wc-settings&tab=checkout&section=' . strtolower($gateway->id)),
			'support' => $gateway->supports("pos"),
		];
	}

	public function gateway_settings_fields(\WC_Payment_Gateway $gateway)
	{
		ob_start();
		settings_fields('pos' . $this->path . '/' . $gateway->id);
		$data = ob_get_contents();
		ob_end_clean();

		return $data;
	}
}
