<?php

namespace ZPOS\Admin\Tabs;

use ZPOS\Admin\Setting\Box;
use ZPOS\Admin\Setting\Input\Input;
use ZPOS\Admin\Setting\Input\Media;
use ZPOS\Admin\Setting\Input\DropdownSelect;
use ZPOS\Admin\Setting\Tab;

class General extends Tab
{
	public $exact = true;
	public $name = 'General';
	public $path = '/general';

	public function admin_init()
	{
		$country = get_option('pos_country');
		$state = get_option('pos_state');
		$country_state = $country . ($state ? ":" . $state : "");

		$this->boxes[] = new Box(
			'POS Base Address',
			null,
			new Input('Address line 1', 'pos_address_1', get_option('pos_address_1')),
			new Input('Address line 2', 'pos_address_2', get_option('pos_address_2')),
			new Input('City', 'pos_city', get_option('pos_city')),
			new Input('Postcode / ZIP', 'pos_postcode', get_option('pos_postcode')),
			new DropdownSelect('Country / State', 'pos_country_state', $country_state, $this->get_countries())
		);

		$this->boxes[] = new Box(
			'POS Settings',
			null,
			new Media('Logo', 'pos_logo', $this->media_get_value())
		);
	}

	public function init()
	{
		register_setting('pos' . $this->path, 'pos_logo');

		register_setting('pos' . $this->path, 'pos_address_1');
		register_setting('pos' . $this->path, 'pos_address_2');
		register_setting('pos' . $this->path, 'pos_city');
		register_setting('pos' . $this->path, 'pos_postcode');
		register_setting(
			'pos' . $this->path,
			'pos_country',
			[
				'sanitize_callback' => function () {
					return explode(":", esc_sql($_REQUEST['pos_country_state']))[0];
				}
			]
		);
		register_setting(
			'pos' . $this->path,
			'pos_state',
			[
				'sanitize_callback' => function () {
					$country_state = explode(":", esc_sql($_REQUEST['pos_country_state']));
					return $country_state[1] ? $country_state[1] : "";
				}
			]
		);
	}

	public function get_countries()
	{
		$countries = WC()->countries->get_countries();
		$states = array_reduce(array_keys($countries), function ($acc, $country) use ($countries) {
			$country_name = $countries[$country];
			$states = WC()->countries->get_states($country);

			if ($states) {
				$states = array_map(function ($state) use ($country_name) {
					return $country_name . ' - ' . $state;
				}, $states);
				$states_keys = array_map(function ($state) use ($country) {
					return $country . ':' . $state;
				}, array_keys($states));
				$states = array_combine($states_keys, $states);

				$acc = array_merge($acc, $states);
			} else {
				$acc[$country] = $country_name;
			}
			return $acc;
		}, []);
		return array_map(function ($value, $label) {
			return compact('value', 'label');
		}, array_keys($states), $states);
	}

	protected function media_get_value()
	{
		$id = get_option('pos_logo');
		$src = null;
		if ($id) {
			$src_data = wp_get_attachment_image_src($id, 'full');
			$src = $src_data[0];
		}

		return compact('id', 'src');
	}
}
