<?php

namespace ZPOS\Admin\Tabs;

use ZPOS\Admin\Setting\Box;
use ZPOS\Admin\Setting\Input\Select;
use ZPOS\Admin\Setting\Input\TaxArray;
use ZPOS\Admin\Setting\Tab;

class Tax extends Tab
{
	public $name = 'Tax';
	public $path = '/tax';

	public static $enabled = [
		['value' => 'on', 'label' => 'Enabled (using WooCommerce configurations)'],
		['value' => 'off', 'label' => 'Disabled']
	];

	public static $calculate_on = [
		'pos' => 'POS base address',
		'wc' => 'Default WooCommerce Shop Base',
		'shipping' => 'Customer shipping address',
		'billing' => 'Customer billing address',
	];

	public function admin_init()
	{
		$this->boxes[] = new Box(
			'Tax Options',
			null,
			new Select('Tax Calculation', 'pos_tax_enabled', get_option('pos_tax_enabled'), static::$enabled),
			new TaxArray('Calculate Tax Based on', 'pos_tax_based_on_order', $this->get_tax_based_on())
		);
	}

	protected function get_tax_based_on()
	{
		return array_map(function ($value) {
			return ['value' => $value, 'label' => static::$calculate_on[$value]];
		}, get_option('pos_tax_based_on_order'));
	}

	public function init()
	{
		register_setting('pos' . $this->path, 'pos_tax_enabled', [
			'default' => 'on'
		]);

		register_setting('pos' . $this->path, 'pos_tax_based_on_order', [
			'default' => ['shipping', 'billing', 'pos', 'wc']
		]);
	}
}
