<?php

namespace ZPOS\Admin\Tabs\Users;

use ZPOS\Admin\Setting\Box;
use ZPOS\Admin\Setting\Input\UserRights;
use ZPOS\Structure\ArrayObject;

class Access extends Box
{
	protected $label = "User Access";

	private static $user_manage_rights = [
		'manage_woocommerce_pos',
		'access_woocommerce_pos',
		'read_private_products',
		'read_private_shop_orders',
		'publish_shop_orders',
		'list_users',
		'edit_product',
		'edit_published_products',
		'edit_others_products',
		'edit_users',
		'create_users',
		'read_private_shop_coupons',
	];

	private static $user_roles = [
		'administrator',
		'customer',
		'shop_manager',
		'cashier',
		'kiosk'
	];


	public function __construct()
	{
		parent::__construct($this->label, null, new UserRights(null, 'pos_user_rights', $this->getUserRights()));
	}

	public function getUserRights()
	{
		return get_option('pos_user_rights');
	}

	public static function init($path)
	{
		register_setting('pos' . $path, 'pos_user_rights', [
			'sanitize_callback' => function ($data) {
				$data = array_filter($data, function ($key) {
					return in_array($key, static::$user_roles);
				}, ARRAY_FILTER_USE_KEY);
				$data = array_map(function ($role_right) {
					$role_right_default = static::get_default_value();
					$role_right = array_filter($role_right, function ($key) {
						return in_array($key, static::$user_manage_rights);
					}, ARRAY_FILTER_USE_KEY);
					$role_right = array_map('__return_true', $role_right);

					return array_merge($role_right_default, $role_right);
				}, $data);

				foreach ($data as $role => $role_rights) {
					$role = get_role($role);
					foreach ($role_rights as $role_right => $value) {
						if ($value) {
							$role->add_cap($role_right);
						} else {
							$role->remove_cap($role_right);
						}
					}
				}

				return false;
			}
		]);

		add_filter('pre_option_pos_user_rights', [static::class, 'get_value']);
	}

	public static function get_value()
	{
		$roles = static::$user_roles;

		$roles = array_filter($roles, function ($role) {
			return get_role($role);
		});

		$roles = array_combine($roles, array_map(function ($role) {
			$role = get_role($role);
			$capabilities = $role->capabilities;
			$name = ucwords(str_replace('_', ' ', $role->name));
			$default = static::get_default_value();

			$capabilities = array_filter($capabilities, function ($cap) {
				return in_array($cap, static::$user_manage_rights);
			}, ARRAY_FILTER_USE_KEY);

			$capabilities = array_merge($default, $capabilities);

			return compact('capabilities', 'name');
		}, $roles));

		return $roles;
	}

	public static function get_default_value()
	{
		return array_combine(static::$user_manage_rights, array_fill(0, count(static::$user_manage_rights), false));
	}
}
