<?php

namespace ZPOS;

class Plugin
{
	const ASSETS = 'assets';
	const ASSETS_CORE = self::ASSETS . DIRECTORY_SEPARATOR . 'core';

	public static function getManifest($file = null)
	{
		$manifest = implode(DIRECTORY_SEPARATOR, [PLUGIN_ROOT, self::ASSETS_CORE, 'manifest.json']);
		if (file_exists($manifest)) {
			$manifest = json_decode(file_get_contents($manifest), true);
		} else {
			$manifest = [];
		}

		if ($file !== null) {
			return isset($manifest[$file]) ? $manifest[$file] : null;
		} else {
			return $manifest;
		}
	}

	public static function getAssetUrl($file, $core = true)
	{
		$manifest_path = self::getManifest($file);

		$base_path = $file;

		if ($manifest_path != null) {
			$base_path = $manifest_path;
		}

		$base = ($core) ? self::ASSETS_CORE : self::ASSETS;

		$path = $base . DIRECTORY_SEPARATOR . $base_path;

		return self::getUrl($path);
	}

	public static function getUrl($path, $raw = false)
	{
		$plugin_data = get_plugin_data(PLUGIN_ROOT_FILE);
		$url = plugins_url($path, PLUGIN_ROOT_FILE);

		if ($raw) {
			return $url;
		}

		return add_query_arg('version', $plugin_data['Version'], $url);
	}

	public static function isMobileApp()
	{
		$is_mobile_app = isset($_SERVER['HTTP_IS_MOBILE_DEVICE']) && filter_var($_SERVER['HTTP_IS_MOBILE_DEVICE'], FILTER_VALIDATE_BOOLEAN);

		return $is_mobile_app;
	}
}
